<?php
/**
 * Plugin Name:       Ninja Forms: GDPR Framework Add-On
 * Plugin URI:        https://www.data443.com/gdpr-framework-wordpress-plugin/
 * Description:       The easiest way to make your Ninja Forms GDPR-compliant. Fully documented, extendable and developer-friendly.
 * Requires at least: 4.7
 * Requires PHP:      5.6
 * Version:           2.0.0
 * Author:            Data443
 * Author URI:        https://www.data443.com/
 * Text Domain:       gdpr-for-ninja-forms
 * Domain Path:       /languages
 */

require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if (!defined('WPINC')) {
    die;
}

define('NF_GDPR_VERSION', '2.0.0');

$have_gdpr_pro = false;

add_action('plugins_loaded', function () {
    global $have_gdpr_pro;

    if (!class_exists('Ninja_Forms')) {
        add_action('admin_notices', function () {
            $class   = 'notice notice-error';
            $message = __('It seems your Ninja Forms plugin is not activated. Ninja Forms GDPR Add-On will not function.', 'gdpr-for-ninja-forms');

            printf('<div class="%1$s"><p>%2$s</p></div>', $class, $message);
        });
        deactivate_plugins( plugin_basename( __FILE__ ) );
        unset($_GET['activate']);
        return;
    }

    $have_gdpr = false;

    if (function_exists('gdpr')) {
        $have_gdpr = true;
    }

    if (function_exists('gdpr_pro')) {
        $have_gdpr_pro = true;
    }

    if (!$have_gdpr && !$have_gdpr_pro) {
        add_action('admin_notices', function () {
            $class   = 'notice notice-error';
            $message =
                sprintf(
                    __("Ninja Forms GDPR Add-On currently requires %sThe GDPR Framework%s to function. Get it from the %sofficial WordPress plugin repository%s - it's free and fully documented!", 'gdpr-for-ninja-forms'),
                    '<a href="https://wordpress.org/plugins/gdpr-framework/" target="_blank">',
                    '</a>',
                    '<a href="https://wordpress.org/plugins/gdpr-framework/" target="_blank">',
                    '</a>'
                );

            printf('<div class="%1$s"><p>%2$s</p></div>', $class, $message);
        });
        deactivate_plugins( plugin_basename( __FILE__ ) );
        unset($_GET['activate']);
        return;
    }

    require_once('src/NinjaForms.php');
    require_once('includes/Actions/gdpr-import-exportAction.php');

    final class NF_GDPR
    {
        const VERSION = NF_GDPR_VERSION;
        const SLUG    = 'gdpr-import-export';
        const NAME    = 'GDPR Import Export';
        const AUTHOR  = 'The WP Ninjas';
        const PREFIX  = 'NF_GDPR';

        /**
         * @var Campaign Monitor Api Call
         */
        private $_api;

        /**
         * @var NF_GDPR
         * @since 1.0
         */
        private static $instance;

        /**
         * Plugin Directory
         *
         * @since 1.0
         * @var string $dir
         */
        public static $dir = '';

        /**
         * Plugin URL
         *
         * @since 1.0
         * @var string $url
         */
        public static $url = '';

        /**
         * Main Plugin Instance
         *
         * Insures that only one instance of a plugin class exists in memory at any one
         * time. Also prevents needing to define globals all over the place.
         *
         * @since 1.0
         * @static
         * @static var array $instance
         * @return NF_GDPR Highlander Instance
         */
        public static function instance()
        {
            if (!isset(self::$instance) && !(self::$instance instanceof NF_GDPR)) {
                self::$instance = new NF_GDPR();

                self::$dir = plugin_dir_path(__FILE__);

                self::$url = plugin_dir_url(__FILE__);

                /*
                 * Register our autoloader
                 */
                spl_autoload_register(array(self::$instance, 'autoloader'));
            }
            return self::$instance;
        }

        public function __construct()
        {
            /*
             * Required for all Extensions.
             */
            add_action( 'admin_init', array( $this, 'setup_license') );
            /*
             * Optional. If your extension processes or alters form submission data on a per form basis...
             */
            add_filter( 'ninja_forms_register_actions', array( $this, 'register_actions' ) );

        }

        /**
         * Optional. If your extension processes or alters form submission data on a per form basis...
         */
        public function register_actions($actions)
        {
            $actions[ 'gdprdatarequest' ] = new NF_GDPR_Actions_GDPR(); // includes/Actions/gdpr-import-exportAction.php

            return $actions;
        }

        /*
         * Optional methods for convenience.
         */

        public function autoloader($class_name)
        {   
            if (class_exists($class_name)) return;
            if ( false === strpos( $class_name, self::PREFIX ) ) return;

            $class_name = str_replace( self::PREFIX, '', $class_name );
            $classes_dir = realpath(plugin_dir_path(__FILE__)) . DIRECTORY_SEPARATOR . 'includes';
            $class_file = str_replace('_', DIRECTORY_SEPARATOR, $class_name) . '.php';
            if (file_exists($classes_dir . $class_file)) {
                require_once $classes_dir . $class_file;
            }
        }
                
        /**
         * Config
         *
         * @param $file_name
         * @return mixed
         */
        public static function config( $file_name )
        {
            return include self::$dir . 'includes/Config/' . $file_name . '.php';
        }

        /*
         * Required methods for all extension.
         */

        public function setup_license()
        {
            if ( ! class_exists( 'NF_Extension_Updater' ) ) return;

            new NF_Extension_Updater( self::NAME, self::VERSION, self::AUTHOR, __FILE__, self::SLUG );
        }

    }
    function NF_GDPR()
    {
        return NF_GDPR::instance();
    }
    NF_GDPR();

    global $gdpr;
    new \data443\GDPR\Modules\NinjaForms\NinjaForms($gdpr->DataSubject, $gdpr->Consent);
}, 5);
